@@ -2,7 +2,6 @@ import ujson
 import pydash
 import phpserialize
 import regex as re
-import markdown
 from lxml import etree
 from ..core import ChepyCore, ChepyDecorators
 
@@ -67,7 +66,6 @@ class CodeTidy(ChepyCore):
             >>> c = Chepy("/path/to/file.xml").load_file()
             >>> print(c.beautify_json())
         """
-        parser = etree.XMLParser(remove_blank_text=True)
         self.state = etree.tostring(
             etree.fromstring(self._convert_to_bytes()), pretty_print=True
         )
@@ -221,14 +219,3 @@ class CodeTidy(ChepyCore):
         """
         self.state = pydash.swap_case(self._convert_to_str())
         return self
-
-    @ChepyDecorators.call_stack
-    def markdown_to_html(self):
-        """Convert markdown syntax to html
-        
-        Returns:
-            Chepy: The Chepy object. 
-        """
-        self.state = markdown.markdown(self._convert_to_str())
-        return self
-
