@@ -1,11 +1,42 @@
 from OpenSSL import crypto as _pyssl_crypto
-from OpenSSL._util import lib as _pyssl_cryptolib
 from Crypto.PublicKey import RSA
 
 from ..core import ChepyCore, ChepyDecorators
 
 
 class Publickey(ChepyCore):
+    def _convert_cert_to_obj(self, cert):
+        issuer = cert.get_issuer()
+        subject = cert.get_subject()
+        pubkey = cert.get_pubkey()
+        info = {
+            "version": cert.get_version(),
+            "serial": cert.get_serial_number(),
+            "algo": cert.get_signature_algorithm(),
+            "before": cert.get_notBefore(),
+            "after": cert.get_notAfter(),
+            "issuer": {
+                "C": issuer.C,
+                "ST": issuer.ST,
+                "L": issuer.L,
+                "O": issuer.O,
+                "OU": issuer.OU,
+                "CN": issuer.CN,
+                "email": issuer.emailAddress,
+            },
+            "subject": {
+                "C": subject.C,
+                "ST": subject.ST,
+                "L": subject.L,
+                "O": subject.O,
+                "OU": subject.OU,
+                "CN": subject.CN,
+                "email": subject.emailAddress,
+            },
+            "pubkey": {"bits": pubkey.bits()},
+        }
+        return info
+
     @ChepyDecorators.call_stack
     def parse_x509_pem(self):
         """Parse X509 cert in PEM format
@@ -40,36 +71,7 @@ class Publickey(ChepyCore):
         cert = _pyssl_crypto.load_certificate(
             _pyssl_crypto.FILETYPE_PEM, self._convert_to_str()
         )
-        issuer = cert.get_issuer()
-        subject = cert.get_subject()
-        pubkey = cert.get_pubkey()
-        bio = _pyssl_crypto._new_mem_buf()
-        info = {
-            "version": cert.get_version(),
-            "serial": cert.get_serial_number(),
-            "algo": cert.get_signature_algorithm(),
-            "before": cert.get_notBefore(),
-            "after": cert.get_notAfter(),
-            "issuer": {
-                "C": issuer.C,
-                "ST": issuer.ST,
-                "L": issuer.L,
-                "O": issuer.O,
-                "OU": issuer.OU,
-                "CN": issuer.CN,
-                "email": issuer.emailAddress,
-            },
-            "subject": {
-                "C": subject.C,
-                "ST": subject.ST,
-                "L": subject.L,
-                "O": subject.O,
-                "OU": subject.OU,
-                "CN": subject.CN,
-                "email": subject.emailAddress,
-            },
-            "pubkey": {"bits": pubkey.bits()},
-        }
+        info = self._convert_cert_to_obj(cert)
         self.state = info
         return self
 
@@ -88,36 +90,7 @@ class Publickey(ChepyCore):
         cert = _pyssl_crypto.load_certificate(
             _pyssl_crypto.FILETYPE_ASN1, self._convert_to_bytes()
         )
-        issuer = cert.get_issuer()
-        subject = cert.get_subject()
-        pubkey = cert.get_pubkey()
-        bio = _pyssl_crypto._new_mem_buf()
-        info = {
-            "version": cert.get_version(),
-            "serial": cert.get_serial_number(),
-            "algo": cert.get_signature_algorithm(),
-            "before": cert.get_notBefore(),
-            "after": cert.get_notAfter(),
-            "issuer": {
-                "C": issuer.C,
-                "ST": issuer.ST,
-                "L": issuer.L,
-                "O": issuer.O,
-                "OU": issuer.OU,
-                "CN": issuer.CN,
-                "email": issuer.emailAddress,
-            },
-            "subject": {
-                "C": subject.C,
-                "ST": subject.ST,
-                "L": subject.L,
-                "O": subject.O,
-                "OU": subject.OU,
-                "CN": subject.CN,
-                "email": subject.emailAddress,
-            },
-            "pubkey": {"bits": pubkey.bits()},
-        }
+        info = self._convert_cert_to_obj(cert)
         self.state = info
         return self
 
@@ -128,12 +101,12 @@ class Publickey(ChepyCore):
         Returns:
             Chepy: The Chepy object. 
         """
-        crtObj = _pyssl_crypto.load_certificate(_pyssl_crypto.FILETYPE_PEM, self.state)
-        pubKeyObject = crtObj.get_pubkey()
-        pubKeyString = _pyssl_crypto.dump_publickey(
-            _pyssl_crypto.FILETYPE_PEM, pubKeyObject
+        crt_obj = _pyssl_crypto.load_certificate(_pyssl_crypto.FILETYPE_PEM, self.state)
+        pub_key_object = crt_obj.get_pubkey()
+        pub_key_string = _pyssl_crypto.dump_publickey(
+            _pyssl_crypto.FILETYPE_PEM, pub_key_object
         )
-        self.state = pubKeyString
+        self.state = pub_key_string
         return self
 
     @ChepyDecorators.call_stack
